--Defines functions used to manipulate entities and ships.

--Megadroid

Entity = {}

Entity.mt = {}

Entity.mt.__index = Entity

Entity.Alert = { Red = 0, Yellow = 1, Green = 2 }
Entity.MovementAutonomy = { Low = 0, Medium = 1, High = 2 }
Entity.SpecialWeaponAutonomy = { Low = 0, Medium = 1, High = 2 }

--Base entity functions

function Entity:new( i )
	return setmetatable( { id = i }, Entity.mt )
end

--Returns if this entity is a craft or not
function Entity:isCraft( )
	return _EntityIsCraft( self.id )
end

--Returns if this entity is a planet or not
function Entity:isPlanet( ) 
	return _EntityIsPlanet( self.id )
end

--Returns true if the user can see the entity
function Entity:canUserSee( )
	return _EntityCanUserSee( self.id )
end

--Get the current position of this entity
function Entity:getPosition( )
	local pos = _EntityGetPosition( self.id )
	return Vector3:new( pos.x, pos.y, pos.z )
end

function Entity:setPosition( pos )
	_EntitySetPosition( self.id, pos.x, pos.y, pos.z )
end

--Game object functions

--Makes the object cloak, if it has a cloaking device.
function Entity:cloak( )
	_GameObjectCloak( self.id )
end

--Immediately cloaks the object if it has a cloaking device
function Entity:immediateCloak( )
	_GameObjectImmediateCloak( self.id )
end

--Returns true if the object is cloaked
function Entity:isCloaked( )
	return _GameObjectIsCloaked( self.id )
end

--Returns true if the craft can cloak
function Entity:canCloak( )
	return _GameObjectCanCloak( self.id )
end

function Entity:getTeam( )
	return _GameObjectGetTeam( self.id )
end

--Sets the team of the object.
function Entity:setTeam( team )
	_GameObjectSetTeam( self.id, team )
end

--Returns true if the object has been destroyed.
function Entity:isDestroyed( )
	return _GameObjectIsDestroyed( self.id )
end

--Get the name of the odf
function Entity:getOdfName( ) 
	return _GameObjectGetOdfName( self.id )
end

function Entity:isAIControlled( )
	return _GameObjectIsAIControlled( self.id )
end

--Tell the craft to move to a position
function Entity:giveMoveOrderPos( position )
	return _GameObjectGiveMoveOrderPos( self.id, position.x, position.y, position.z )
end

function Entity:giveMoveOrderEntity( position )
	
end

--Craft functions

--If this entity is a craft, then this function will
--return the name of the craft.
function Entity:getCraftName( ) 
	if not self:isCraft( ) then return nil end
	return _CraftGetName( self.id )	
end

--If this entity is a craft, then this function will 
--set the name of the craft.
function Entity:setCraftName( name )
	if not self:isCraft( ) then return false end
	return _CraftSetName( self.id, name )
end

--Makes the craft blow up. Dont blow up planets. Not good.
function Entity:explode( )
	if not self:isCraft( ) then return end
	_CraftExplode( self.id )
end

--Get the current alert status of the craft
--See Entity.Alert
function Entity:getAlertStatus( )
	return _CraftGetAlertStatus( self.id )
end

--Set the alert status of the craft.
--See Entity.Alert
function Entity:setAlertStatus( status )
	_CraftSetAlertStatus( self.id, status )
end

--Get the special weapons autonomy value. 
--See Entity.SpecialWeaponAutonomy
function Entity:getSpecialWeaponAutonomy( )
	return _CraftGetSpecialWeaponAutonomy( self.id )
end

--Set the special weapons autonomy value.
--See Entity.SpecialWeaponAutonomy
function Entity:setSpecialWeaponAutonomy( state )
	_CraftSetSpecialWeaponAutonomy( self.id, state )
end

--Get the movement autonomy value
--See Entity.MovementAutonomy
function Entity:getMovementAutonomy( )
	return _CraftGetMovementAutonomy( self.id )
end

--Set the movement autonomy.
--See Entity.MovementAutonomy
function Entity:setMovementAutonomy( state )
	_CraftSetMovementAutonomy( self.id, state )
end

--Get the current value of the crafts shields. This is a value between
--0 and 1.
function Entity:getShields( )
	return _CraftGetShields( self.id )
end

